summaryrefslogtreecommitdiff
path: root/src/debug
diff options
context:
space:
mode:
authorSteve MacLean <sdmaclea.qdt@qualcommdatacenter.com>2017-06-12 17:14:12 -0400
committerMaoni Stephens <Maoni0@users.noreply.github.com>2017-06-12 14:14:12 -0700
commit0ee3b5e64a98dc71aefed2304fe4bcf7f66ca9f5 (patch)
tree8f099e2391d8990de1c7d0f4ca4c3fcae6839e4d /src/debug
parentc655981474be1d3aa0165408e5c3914c5cfc35a1 (diff)
downloadcoreclr-0ee3b5e64a98dc71aefed2304fe4bcf7f66ca9f5.tar.gz
coreclr-0ee3b5e64a98dc71aefed2304fe4bcf7f66ca9f5.tar.bz2
coreclr-0ee3b5e64a98dc71aefed2304fe4bcf7f66ca9f5.zip
[Arm64/Unix] Add 64K page support (#10981)
* [Arm64/Unix] Support 64K pages * GC move GCToOSInterface::Initialize() into InitializeGarbageCollector()
Diffstat (limited to 'src/debug')
-rw-r--r--src/debug/daccess/enummem.cpp4
-rw-r--r--src/debug/daccess/nidump.cpp2
-rw-r--r--src/debug/di/shimlocaldatatarget.cpp2
3 files changed, 4 insertions, 4 deletions
diff --git a/src/debug/daccess/nidump.cpp b/src/debug/daccess/nidump.cpp
index 62b68ef89d..81874a26ca 100644
--- a/src/debug/daccess/nidump.cpp
+++ b/src/debug/daccess/nidump.cpp
@@ -685,7 +685,7 @@ NativeImageDumper::DumpNativeImage()
* I don't understand this. Sections start on a two page boundary, but
* data ends on a one page boundary. What's up with that?
*/
- m_sectionAlignment = PAGE_SIZE; //ntHeaders->OptionalHeader.SectionAlignment;
+ m_sectionAlignment = GetOsPageSize(); //ntHeaders->OptionalHeader.SectionAlignment;
unsigned ntHeaderSize = sizeof(*ntHeaders)
- sizeof(ntHeaders->OptionalHeader)
+ ntHeaders->FileHeader.SizeOfOptionalHeader;
diff --git a/src/debug/di/shimlocaldatatarget.cpp b/src/debug/di/shimlocaldatatarget.cpp
index c4a5263810..36ea611af2 100644
--- a/src/debug/di/shimlocaldatatarget.cpp
+++ b/src/debug/di/shimlocaldatatarget.cpp
@@ -322,7 +322,7 @@ ShimLocalDataTarget::ReadVirtual(
{
// Calculate bytes to read and don't let read cross
// a page boundary.
- readSize = OS_PAGE_SIZE - (ULONG32)(address & (OS_PAGE_SIZE - 1));
+ readSize = GetOsPageSize() - (ULONG32)(address & (GetOsPageSize() - 1));
readSize = min(cbRequestSize, readSize);
if (!ReadProcessMemory(m_hProcess, (PVOID)(ULONG_PTR)address,
diff --git a/src/debug/daccess/enummem.cpp b/src/debug/daccess/enummem.cpp
index bc110c8564..6cd210f3dc 100644
--- a/src/debug/daccess/enummem.cpp
+++ b/src/debug/daccess/enummem.cpp
@@ -116,7 +116,7 @@ HRESULT ClrDataAccess::EnumMemCollectImages()
ulSize = file->GetLoadedIL()->GetSize();
}
// memory are mapped in in OS_PAGE_SIZE size.
// Some memory are mapped in but some are not. You cannot
// write all in one block. So iterating through page size
//
@@ -129,7 +129,7 @@ HRESULT ClrDataAccess::EnumMemCollectImages()
// MethodHeader MethodDesc::GetILHeader. Without this RVA,
// all locals are broken. In case, you are asked about this question again.
//
- ulSizeBlock = ulSize > OS_PAGE_SIZE ? OS_PAGE_SIZE : ulSize;
+ ulSizeBlock = ulSize > GetOsPageSize() ? GetOsPageSize() : ulSize;
ReportMem(pStartAddr, ulSizeBlock, false);
pStartAddr += ulSizeBlock;
ulSize -= ulSizeBlock;
@@ -116,7 +116,7 @@ HRESULT ClrDataAccess::EnumMemCollectImages()
ulSize = file->GetLoadedIL()->GetSize();
}
- // memory are mapped in in OS_PAGE_SIZE size.
+ // memory are mapped in in GetOsPageSize() size.
// Some memory are mapped in but some are not. You cannot
// write all in one block. So iterating through page size